==> apache-camel-3.14.9-src.zip: apache-camel-3.14.9/components/camel-aws/camel-aws2-athena/src/test/java/org/apache/camel/component/aws2/athena/AthenaComponentClientRegistryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.athena;

import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertSame;
import static org.junit.jupiter.api.Assertions.assertThrows;

public class AthenaComponentClientRegistryTest extends CamelTestSupport {

    @Test
    public void createEndpointWithMinimalAthenaClientConfiguration() throws Exception {
        AmazonAthenaClientMock clientMock = new AmazonAthenaClientMock();
        context.getRegistry().bind("amazonAthenaClient", clientMock);
        Athena2Component component = context.getComponent("aws2-athena", Athena2Component.class);
        Athena2Endpoint endpoint = (Athena2Endpoint) component.createEndpoint("aws2-athena://label");

        assertEquals(clientMock, endpoint.getConfiguration().getAmazonAthenaClient());
    }

    @Test
    public void createEndpointWithMinimalAthenaClientMisconfiguration() throws Exception {
        Athena2Component component = context.getComponent("aws2-athena", Athena2Component.class);
        assertThrows(IllegalArgumentException.class, () -> component.createEndpoint("aws2-athena://label"));
    }

    @Test
    public void createEndpointWithAutowire() throws Exception {
        AmazonAthenaClientMock clientMock = new AmazonAthenaClientMock();
        context.getRegistry().bind("amazonAthenaClient", clientMock);
        Athena2Component component = context.getComponent("aws2-athena", Athena2Component.class);
        Athena2Endpoint endpoint
                = (Athena2Endpoint) component.createEndpoint("aws2-athena://label?accessKey=xxx&secretKey=yyy");

        assertSame(clientMock, endpoint.getConfiguration().getAmazonAthenaClient());
    }
}

==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/components/camel-aws/camel-aws2-athena/src/test/java/org/apache/camel/component/aws2/athena/AthenaComponentClientRegistryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.athena;

import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertSame;
import static org.junit.jupiter.api.Assertions.assertThrows;

public class AthenaComponentClientRegistryTest extends CamelTestSupport {

    @Test
    public void createEndpointWithMinimalAthenaClientConfiguration() throws Exception {
        AmazonAthenaClientMock clientMock = new AmazonAthenaClientMock();
        context.getRegistry().bind("amazonAthenaClient", clientMock);
        Athena2Component component = context.getComponent("aws2-athena", Athena2Component.class);
        Athena2Endpoint endpoint = (Athena2Endpoint) component.createEndpoint("aws2-athena://label");

        assertEquals(clientMock, endpoint.getConfiguration().getAmazonAthenaClient());
    }

    @Test
    public void createEndpointWithMinimalAthenaClientMisconfiguration() {
        Athena2Component component = context.getComponent("aws2-athena", Athena2Component.class);
        assertThrows(IllegalArgumentException.class, () -> component.createEndpoint("aws2-athena://label"));
    }

    @Test
    public void createEndpointWithAutowire() throws Exception {
        AmazonAthenaClientMock clientMock = new AmazonAthenaClientMock();
        context.getRegistry().bind("amazonAthenaClient", clientMock);
        Athena2Component component = context.getComponent("aws2-athena", Athena2Component.class);
        Athena2Endpoint endpoint
                = (Athena2Endpoint) component.createEndpoint("aws2-athena://label?accessKey=xxx&secretKey=yyy");

        assertSame(clientMock, endpoint.getConfiguration().getAmazonAthenaClient());
    }
}
